mod unar;

use std::fs;
use std::io::Result;
use std::path::{Path, PathBuf};
use std::{env, io};

fn is_compressed(path: &Path) -> bool {
    if let Some(ext) = path.extension() {
        if let Some(ext) = ext.to_str() {
            let ext = ext.to_lowercase();
            return ext == "zip" || ext == "rar" || ext == "7z";
        }
    }

    false
}

fn process_compressed_files(path: &Path) -> Result<()> {
    if !path.is_dir() {
        return Err(io::Error::new(io::ErrorKind::Other, "Not a directory"));
    }

    println!("Processing directory: {:?}", path);
    let mut waiting_files: Vec<PathBuf> = Vec::new();
    for entry in fs::read_dir(path)? {
        let entry_path: PathBuf = entry?.path();
        if entry_path.is_dir() {
            process_compressed_files(&entry_path)?;
        } else if is_compressed(entry_path.as_path()) {
            waiting_files.push(entry_path);
        }
    }

    for f in waiting_files {
        unar::unar_file(&f).expect("UNAR Error.");
    }

    Ok(())
}

fn main() -> Result<()> {
    let args: Vec<String> = env::args().collect();

    let start_path = if args.len() > 1 {
        PathBuf::from(args[1].as_str())
    } else {
        PathBuf::from(".")
    };

    if start_path.is_file() {
        return unar::unar_file(&start_path);
    }

    process_compressed_files(&start_path)
}
