use std::io;
use std::path::Path;
use std::process::{Command, Stdio};

pub fn unar_file(path: &Path) -> io::Result<()> {
    println!("UNAR: {}", path.display());
    let parent_dir = if path.parent().unwrap().exists() {
        path.parent().unwrap()
    } else {
        Path::new(".")
    };

    let filename = path.canonicalize()?;

    let output = Command::new("unar")
        .current_dir(parent_dir)
        .arg("-s") // -force-skip: skip if exists
        .arg(filename)
        .stdout(Stdio::inherit())
        .stderr(Stdio::inherit())
        .spawn()?.wait_with_output();

    match output {
        Ok(res) => {
            if !res.status.success() {
                eprintln!("Error processing compressed file {:?}: {}", path, String::from_utf8_lossy(&res.stderr));
                return Err(io::ErrorKind::Other.into());
            }
        }

        Err(e) => {
            eprintln!("Failed to execute unar for {:?}: {}", path, e);
        }
    }

    Ok(())
}
